@@ -11,15 +11,13 @@
 
 #include <QObject>
 
-#include <QDBusObjectPath>
-
 class Bearer : public QObject
 {
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.kde.fakemodem.Bearer")
 public:
-    explicit Bearer(QObject * parent = nullptr);
-    virtual ~Bearer();
+    explicit Bearer(QObject *parent = nullptr);
+    ~Bearer() override;
 
     Q_PROPERTY(bool Connected READ connected)
     Q_PROPERTY(QString Interface READ interface)
